@@ -1,5 +1,3 @@
-# $Id: RequestFactory.pm 348 2008-12-09 05:29:27Z rcaputo $
-
 package POE::Component::Client::HTTP::RequestFactory;
 use strict;
 use warnings;
@@ -21,7 +19,7 @@ use constant FCT_TIMEOUT         => 9;
 use constant DEBUG               => 0;
 use constant DEFAULT_BLOCK_SIZE  => 4096;
 
-our $VERSION = "0.01";
+our $VERSION = "0.891";
 
 =head1 CONSTRUCTOR
 
@@ -265,11 +263,19 @@ sub create_request {
   # Create a progress postback if requested.
   my $progress_postback;
   if (defined $progress_event) {
-    $progress_postback = $sender->postback(
-      $progress_event,
-      $http_request,
-      $tag
-    );
+    if (ref $progress_event) {
+      # The given progress event appears to already
+      # be a postback, so use it.  This is needed to
+      # propagate the postback through redirects.
+      $progress_postback = $progress_event;
+    }
+    else {
+      $progress_postback = $sender->postback(
+        $progress_event,
+        $http_request,
+        $tag
+      );
+    }
   }
 
   # If we have a cookie jar, have it add the appropriate headers.
@@ -306,7 +312,7 @@ sub create_request {
     Request => $http_request,
     Proxy => $proxy,
     Postback => $postback,
-    Tag => $tag,
+    #Tag => $tag, # TODO - Is this needed for anything?
     Progress => $progress_postback,
     Factory => $self,
   );
